!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = rad  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = slider_crank
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .slider_crank.steel  &
   adams_id = 1  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29  &
   density = 7.801E-006
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .slider_crank.ground.MARKER_9  &
   adams_id = 9  &
   location = 150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.ground.MARKER_11  &
   adams_id = 11  &
   location = -150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
part create rigid_body mass_properties  &
   part_name = .slider_crank.ground  &
   material_type = .slider_crank.steel
!
part attributes  &
   part_name = .slider_crank.ground  &
   name_visibility = off  &
   size_of_icons = 100.0
!
!----------------------------------- crank ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.ground
!
part create rigid_body name_and_position  &
   part_name = .slider_crank.crank  &
   adams_id = 6  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.crank
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_6  &
   adams_id = 6  &
   location = 60.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_7  &
   adams_id = 7  &
   location = 150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.crank.cm  &
   adams_id = 19  &
   location = 105.0, 0.0, 0.0  &
   orientation = 4.7123889804, 1.5707963268, 1.5707963268
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_8  &
   adams_id = 8  &
   location = 150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_14  &
   adams_id = 14  &
   location = 60.0, 0.0, 0.0  &
   orientation = 4.7123889804, 1.5707963268, 3.1415926536
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_21  &
   adams_id = 21  &
   location = 60.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.crank.MARKER_23  &
   adams_id = 23  &
   location = 60.0, 0.0, 0.0  &
   orientation = 2.9821988932, 0.2012495435, 3.2815087299
!
part create rigid_body mass_properties  &
   part_name = .slider_crank.crank  &
   material_type = .slider_crank.steel
!
! ****** Graphics for current part ******
!
geometry create shape link  &
   link_name = .slider_crank.crank.LINK_5  &
   i_marker = .slider_crank.crank.MARKER_6  &
   j_marker = .slider_crank.crank.MARKER_7  &
   width = 9.0  &
   depth = 4.5
!
part attributes  &
   part_name = .slider_crank.crank  &
   color = MAGENTA  &
   name_visibility = off  &
   size_of_icons = 100.0
!
!---------------------------------- cylinder ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.ground
!
part create rigid_body name_and_position  &
   part_name = .slider_crank.cylinder  &
   adams_id = 3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.cylinder
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .slider_crank.cylinder.MARKER_3  &
   adams_id = 3  &
   location = 55.0, 0.0, 0.0  &
   orientation = 4.7123889804, 1.5707963268, 3.1415926536
!
marker create  &
   marker_name = .slider_crank.cylinder.cm  &
   adams_id = 17  &
   location = -47.5, 0.0, 0.0  &
   orientation = 1.5707963268, 1.5707963268, 0.0
!
marker create  &
   marker_name = .slider_crank.cylinder.MARKER_10  &
   adams_id = 10  &
   location = -150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.cylinder.MARKER_12  &
   adams_id = 12  &
   location = -47.5, 0.0, 0.0  &
   orientation = 1.5707963268, 1.5707963268, 0.0
!
marker create  &
   marker_name = .slider_crank.cylinder.MARKER_20  &
   adams_id = 20  &
   location = -150.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
marker create  &
   marker_name = .slider_crank.cylinder.MARKER_22  &
   adams_id = 22  &
   location = -150.0, 0.0, 0.0  &
   orientation = 2.9821988932, 0.2012495435, 3.2815087299
!
part create rigid_body mass_properties  &
   part_name = .slider_crank.cylinder  &
   material_type = .slider_crank.steel
!
! ****** Graphics for current part ******
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.cylinder.MARKER_3
!
geometry create shape revolution  &
   revolution_name = .slider_crank.cylinder.REVOLUTION_2  &
   adams_id = 2  &
   reference_marker = .slider_crank.cylinder.MARKER_3  &
   analytical = yes  &
   points_for_profile = -5.0, 0.0, 0.0  &
      , -10.0, 0.0, 0.0  &
      , -10.0, 0.0, 205.0  &
      , -5.0, 0.0, 205.0  &
      , -5.0, 0.0, 0.0  &
   angle_extent = 6.2831853072  &
   number_of_sides = 20
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.cylinder
!
part attributes  &
   part_name = .slider_crank.cylinder  &
   color = GREEN  &
   visibility = on  &
   name_visibility = off  &
   size_of_icons = 100.0
!
!----------------------------------- piston -----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.ground
!
part create rigid_body name_and_position  &
   part_name = .slider_crank.piston  &
   adams_id = 5  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
defaults coordinate_system  &
   default_coordinate_system = .slider_crank.piston
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .slider_crank.piston.MARKER_5  &
   adams_id = 5  &
   location = 60.0, 0.0, 0.0  &
   orientation = 4.7123889804, 1.5707963268, 3.1415926536
!
marker create  &
   marker_name = .slider_crank.piston.cm  &
   adams_id = 18  &
   location = -40.0, 0.0, 0.0  &
   orientation = 1.5707963268, 1.5707963268, 0.0
!
marker create  &
   marker_name = .slider_crank.piston.MARKER_13  &
   adams_id = 13  &
   location = -47.5, 0.0, 0.0  &
   orientation = 1.5707963268, 1.5707963268, 0.0
!
marker create  &
   marker_name = .slider_crank.piston.MARKER_15  &
   adams_id = 15  &
   location = 60.0, 0.0, 0.0  &
   orientation = 4.7123889804, 1.5707963268, 3.1415926536
!
marker attributes  &
   marker_name = .slider_crank.piston.MARKER_15  &
   color = MAIZE
!
part create rigid_body mass_properties  &
   part_name = .slider_crank.piston  &
   material_type = .slider_crank.steel
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .slider_crank.piston.CYLINDER_4  &
   adams_id = 4  &
   center_marker = .slider_crank.piston.MARKER_5  &
   angle_extent = 6.2831853072  &
   length = 200.0  &
   radius = 5.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .slider_crank.piston  &
   color = CYAN  &
   visibility = on  &
   name_visibility = off  &
   size_of_icons = 100.0
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint revolute  &
   joint_name = .slider_crank.JOINT_1  &
   adams_id = 1  &
   i_marker_name = .slider_crank.crank.MARKER_8  &
   j_marker_name = .slider_crank.ground.MARKER_9
!
constraint attributes  &
   constraint_name = .slider_crank.JOINT_1  &
   name_visibility = off
!
constraint create joint spherical  &
   joint_name = .slider_crank.JOINT_2  &
   adams_id = 2  &
   i_marker_name = .slider_crank.cylinder.MARKER_10  &
   j_marker_name = .slider_crank.ground.MARKER_11
!
constraint attributes  &
   constraint_name = .slider_crank.JOINT_2  &
   name_visibility = off
!
constraint create joint translational  &
   joint_name = .slider_crank.JOINT_3  &
   adams_id = 3  &
   i_marker_name = .slider_crank.cylinder.MARKER_12  &
   j_marker_name = .slider_crank.piston.MARKER_13
!
constraint attributes  &
   constraint_name = .slider_crank.JOINT_3  &
   name_visibility = off
!
constraint create joint hooke  &
   joint_name = .slider_crank.JOINT_4  &
   adams_id = 4  &
   i_marker_name = .slider_crank.crank.MARKER_14  &
   j_marker_name = .slider_crank.piston.MARKER_15
!
constraint attributes  &
   constraint_name = .slider_crank.JOINT_4  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .slider_crank.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=no end_time=1.0E-002 step_size=1.0E-003 model_name=.slider_crank"
!
!---------------------------------- Motions -----------------------------------!
!
!
constraint create motion_generator  &
   motion_name = .slider_crank.MOTION_1  &
   adams_id = 1  &
   type_of_freedom = rotational  &
   joint_name = .slider_crank.JOINT_1  &
   function = ""
!
constraint attributes  &
   constraint_name = .slider_crank.MOTION_1  &
   name_visibility = off
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------------- Measures ----------------------------------!
!
!
measure create point  &
   measure_name = .slider_crank.cm_R_dot  &
   point = .slider_crank.piston.cm  &
   coordinate_rframe = .slider_crank.cylinder.cm  &
   motion_rframe = .slider_crank.ground.MARKER_9  &
   characteristic = translational_velocity  &
   component = z_component  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.cm_R_dot  &
   color = WHITE
!
measure create point  &
   measure_name = .slider_crank.cm_R_ddot  &
   point = .slider_crank.piston.cm  &
   coordinate_rframe = .slider_crank.cylinder.cm  &
   motion_rframe = .slider_crank.ground.MARKER_9  &
   characteristic = translational_acceleration  &
   component = z_component  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.cm_R_ddot  &
   color = WHITE
!
measure create pt2pt  &
   measure_name = .slider_crank.MEA_PT2PT_R  &
   from_point = .slider_crank.crank.MARKER_6  &
   to_point = .slider_crank.cylinder.MARKER_10  &
   characteristic = translational_displacement  &
   component = mag_component  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.MEA_PT2PT_R  &
   color = WHITE
!
measure create function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta_ddot  &
   function = ""  &
   units = "angle"  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.FUNCTION_MEA_theta_ddot  &
   color = WHITE
!
measure create function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta_dot  &
   function = ""  &
   units = "angle"  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.FUNCTION_MEA_theta_dot  &
   color = WHITE
!
measure create function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta  &
   function = ""  &
   units = "angle"  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .slider_crank.FUNCTION_MEA_theta  &
   color = WHITE
!
!---------------------------- Function definitions ----------------------------!
!
!
constraint modify motion_generator  &
   motion_name = .slider_crank.MOTION_1  &
   function = "-30d - 60.0 * time"
!
measure modify function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta_ddot  &
   function = "WDTZ(.slider_crank.cylinder.MARKER_10, .slider_crank.ground.MARKER_11, .slider_crank.ground.MARKER_11, .slider_crank.ground.MARKER_11)"
!
measure modify function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta_dot  &
   function = "WZ(.slider_crank.cylinder.MARKER_10, .slider_crank.ground.MARKER_11, .slider_crank.ground.MARKER_11)"
!
measure modify function  &
   measure_name = .slider_crank.FUNCTION_MEA_theta  &
   function = "AZ(.slider_crank.cylinder.MARKER_10, .slider_crank.ground.MARKER_11)"
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
geometry modify shape cylinder  &
   cylinder_name = .slider_crank.piston.CYLINDER_4  &
   length = (200mm)  &
   radius = (5mm)
!
geometry modify shape link  &
   link_name = .slider_crank.crank.LINK_5  &
   width = (9.0mm)  &
   depth = (4.5mm)
!
material modify  &
   material_name = .slider_crank.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
model display  &
   model_name = slider_crank
