!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = Pendulum
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .Pendulum.steel  &
   adams_id = 1  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29  &
   density = 7.801E-006
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Pendulum.ground.MARKER_7  &
   adams_id = 7  &
   location = 0.0, 500.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.ground.MARKER_14  &
   adams_id = 14  &
   location = -1000.0, -900.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.ground.MARKER_17  &
   adams_id = 17  &
   location = 86.6328082912, -900.0, 0.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Pendulum.ground  &
   material_type = .Pendulum.steel
!
part attributes  &
   part_name = .Pendulum.ground  &
   name_visibility = off
!
!------------------------------------ rod -------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
part create rigid_body name_and_position  &
   part_name = .Pendulum.rod  &
   adams_id = 2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.rod
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Pendulum.rod.MARKER_1  &
   adams_id = 1  &
   location = 0.0, 500.0, 0.0  &
   orientation = 270.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.rod.MARKER_2  &
   adams_id = 2  &
   location = 0.0, -494.0, 0.0  &
   orientation = 270.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.rod.cm  &
   adams_id = 8  &
   location = 0.0, 3.0, 0.0  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Pendulum.rod.MARKER_5  &
   adams_id = 5  &
   location = 0.0, -494.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.rod.MARKER_6  &
   adams_id = 6  &
   location = 0.0, 500.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.rod.MARKER_10  &
   adams_id = 10  &
   location = 0.0, -494.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Pendulum.rod  &
   mass = 2.3804976354  &
   center_of_mass_marker = .Pendulum.rod.MARKER_2  &
   ixx = 0.0  &
   iyy = 0.0  &
   izz = 0.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape link  &
   link_name = .Pendulum.rod.LINK_1  &
   i_marker = .Pendulum.rod.MARKER_1  &
   j_marker = .Pendulum.rod.MARKER_2  &
   width = 30.0  &
   depth = 10.0
!
part attributes  &
   part_name = .Pendulum.rod  &
   color = RED  &
   name_visibility = off
!
!------------------------------------ bob -------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
part create rigid_body name_and_position  &
   part_name = .Pendulum.bob  &
   adams_id = 3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.bob
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Pendulum.bob.MARKER_3  &
   adams_id = 3  &
   location = 0.0, -494.0, -5.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.bob.cm  &
   adams_id = 9  &
   location = 0.0, -494.0, 0.0  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Pendulum.bob.MARKER_4  &
   adams_id = 4  &
   location = 0.0, -494.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.bob.MARKER_11  &
   adams_id = 11  &
   location = 0.0, -494.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Pendulum.bob  &
   material_type = .Pendulum.steel
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .Pendulum.bob.CYLINDER_2  &
   adams_id = 2  &
   center_marker = .Pendulum.bob.MARKER_3  &
   angle_extent = 360.0  &
   length = 10.0  &
   radius = 127.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .Pendulum.bob  &
   color = GREEN  &
   name_visibility = off
!
!--------------------------------- Mass_block ---------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
part create rigid_body name_and_position  &
   part_name = .Pendulum.Mass_block  &
   adams_id = 4  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.Mass_block
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Pendulum.Mass_block.MARKER_12  &
   adams_id = 12  &
   location = 36.6328082912, -850.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.Mass_block.cm  &
   adams_id = 15  &
   location = 86.6328082912, -900.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.Mass_block.MARKER_13  &
   adams_id = 13  &
   location = 86.6328082912, -900.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Pendulum.Mass_block.MARKER_16  &
   adams_id = 16  &
   location = 86.6328082912, -900.0, 0.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Pendulum.Mass_block  &
   mass = 1.0  &
   center_of_mass_marker = .Pendulum.Mass_block.cm  &
   ixx = 0.0  &
   iyy = 0.0  &
   izz = 0.0  &
   ixy = 0.0  &
   izx = 0.0  &
   iyz = 0.0
!
! ****** Graphics for current part ******
!
geometry create shape block  &
   block_name = .Pendulum.Mass_block.BOX_3  &
   adams_id = 3  &
   corner_marker = .Pendulum.Mass_block.MARKER_12  &
   diag_corner_coords = 100.0, -100.0, 200.0
!
part attributes  &
   part_name = .Pendulum.Mass_block  &
   color = RED  &
   name_visibility = off
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint fixed  &
   joint_name = .Pendulum.fixed_rod_bob  &
   adams_id = 1  &
   i_marker_name = .Pendulum.bob.MARKER_4  &
   j_marker_name = .Pendulum.rod.MARKER_5
!
constraint attributes  &
   constraint_name = .Pendulum.fixed_rod_bob  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Pendulum.rev_rod_ground  &
   adams_id = 2  &
   i_marker_name = .Pendulum.rod.MARKER_6  &
   j_marker_name = .Pendulum.ground.MARKER_7  &
   rotational_ic = 5.0d  &
   angular_velocity_ic = 0.0
!
constraint attributes  &
   constraint_name = .Pendulum.rev_rod_ground  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Pendulum.rev_rod_bob  &
   adams_id = 3  &
   i_marker_name = .Pendulum.rod.MARKER_10  &
   j_marker_name = .Pendulum.bob.MARKER_11
!
constraint attributes  &
   constraint_name = .Pendulum.rev_rod_bob  &
   active = off  &
   name_visibility = off
!
constraint create joint translational  &
   joint_name = .Pendulum.JOINT_4  &
   adams_id = 4  &
   i_marker_name = .Pendulum.Mass_block.MARKER_16  &
   j_marker_name = .Pendulum.ground.MARKER_17
!
constraint attributes  &
   constraint_name = .Pendulum.JOINT_4  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
!---------------------------- Adams/View Variables ----------------------------!
!
!
variable create  &
   variable_name = .Pendulum.initial_angle  &
   units = "angle"  &
   range = -1.0, 1.0  &
   use_allowed_values = no  &
   delta_type = relative  &
   real_value = 5.0
!
variable create  &
   variable_name = .Pendulum.rod_length  &
   units = "length"  &
   range = -1.0, 1.0  &
   use_allowed_values = no  &
   delta_type = relative  &
   real_value = 994.0
!
variable create  &
   variable_name = .Pendulum.stiffness  &
   units = "stiffness"  &
   range = -1.0, 1.0  &
   use_allowed_values = no  &
   delta_type = relative  &
   real_value = 9.8696E-003
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .Pendulum.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=no end_time=5.0 number_of_steps=50 model_name=.Pendulum"
!
!-------------------------- Adams/View UDE Instances --------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
undo begin_block suppress = yes
!
ude create instance  &
   instance_name = .Pendulum.SPRING_1  &
   definition_name = .MDI.Forces.spring  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0, 0.0, 0.0
!
ude attributes  &
   instance_name = .Pendulum.SPRING_1  &
   color = RED
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.i_marker  &
   object_value = (.Pendulum.Mass_block.MARKER_13)
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.j_marker  &
   object_value = (.Pendulum.ground.MARKER_14)
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.stiffness_mode  &
   string_value = "linear"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.stiffness_coefficient  &
   real_value = (.Pendulum.stiffness)
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.stiffness_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.damping_mode  &
   string_value = "none"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.damping_coefficient  &
   real_value = (1.6E-002(newton-sec/mm))
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.damping_spline  &
   object_value = (NONE)
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.free_length_mode  &
   string_value = "Design_Length"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.free_length  &
   real_value = 1.0
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.preload  &
   real_value = (-.Pendulum.stiffness * .Pendulum.rod_length * SIN(.Pendulum.initial_angle))
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.i_dynamic_visibility  &
   string_value = "On"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.j_dynamic_visibility  &
   string_value = "Off"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.spring_visibility  &
   string_value = "depends"
!
variable modify  &
   variable_name = .Pendulum.SPRING_1.damper_visibility  &
   string_value = "depends"
!
ude modify instance  &
   instance_name = .Pendulum.SPRING_1
!
undo end_block
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------- Function definitions ----------------------------!
!
!
!-------------------------- Adams/View UDE Instance ---------------------------!
!
!
ude modify instance  &
   instance_name = .Pendulum.SPRING_1
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
marker modify  &
   marker_name = .Pendulum.ground.MARKER_17  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Pendulum.Mass_block.cm))
!
material modify  &
   material_name = .Pendulum.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
marker modify  &
   marker_name = .Pendulum.rod.MARKER_2  &
   location =   &
      (LOC_RELATIVE_TO({994, 0.0, 0.0}, .Pendulum.rod.MARKER_1))  &
   relative_to = .Pendulum.rod
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
geometry modify shape cylinder  &
   cylinder_name = .Pendulum.bob.CYLINDER_2  &
   length = (10.0mm)  &
   radius = (5in)
!
marker modify  &
   marker_name = .Pendulum.Mass_block.MARKER_12  &
   location =   &
      (LOC_RELATIVE_TO({-50, 50, 0}, .Pendulum.Mass_block.cm))  &
   relative_to = .Pendulum.Mass_block
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
marker modify  &
   marker_name = .Pendulum.Mass_block.cm  &
   location =   &
      ({.Pendulum.rod_length * SIN(.Pendulum.initial_angle), -900, 0})  &
   relative_to = .Pendulum.Mass_block
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
marker modify  &
   marker_name = .Pendulum.Mass_block.MARKER_13  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Pendulum.Mass_block.cm))  &
   relative_to = .Pendulum.Mass_block
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
marker modify  &
   marker_name = .Pendulum.Mass_block.MARKER_16  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Pendulum.Mass_block.cm))  &
   relative_to = .Pendulum.Mass_block
!
defaults coordinate_system  &
   default_coordinate_system = .Pendulum.ground
!
geometry modify shape block  &
   block_name = .Pendulum.Mass_block.BOX_3  &
   diag_corner_coords =   &
      (100.0mm),  &
      (-100.0mm),  &
      (200.0mm)
!
constraint modify joint revolute  &
   joint_name = .Pendulum.rev_rod_ground  &
   rotational_ic = (.Pendulum.initial_angle)
!
model display  &
   model_name = Pendulum
