!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = Gyro
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .Gyro.steel  &
   adams_id = 1  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29  &
   density = 7.801E-006
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Gyro.ground.MARKER_12  &
   adams_id = 12  &
   location = 0.0, 450.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.ground.MARKER_20  &
   adams_id = 20  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Gyro.ground  &
   material_type = .Gyro.steel
!
part attributes  &
   part_name = .Gyro.ground  &
   name_visibility = off
!
!--------------------------------- OuterCage ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.ground
!
part create rigid_body name_and_position  &
   part_name = .Gyro.OuterCage  &
   adams_id = 2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.OuterCage
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Gyro.OuterCage.MARKER_1  &
   adams_id = 1  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.OuterCage.cm  &
   adams_id = 6  &
   location = 0.0, 17.3979998734, 0.0  &
   orientation = 180.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Gyro.OuterCage.MARKER_10  &
   adams_id = 10  &
   location = 0.0, 350.0, 0.0  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Gyro.OuterCage.MARKER_11  &
   adams_id = 11  &
   location = 0.0, 450.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.OuterCage.MARKER_13  &
   adams_id = 13  &
   location = 350.0, 0.0, 0.0  &
   orientation = 270.0d, 90.0d, 90.0d
!
part create rigid_body mass_properties  &
   part_name = .Gyro.OuterCage  &
   material_type = .Gyro.steel
!
! ****** Graphics for current part ******
!
geometry create shape torus  &
   adams_id = 1  &
   torus_name = .Gyro.OuterCage.TORUS_1  &
   center_marker = .Gyro.OuterCage.MARKER_1  &
   angle_extent = 360.0  &
   major_radius = 350.0  &
   minor_radius = 10.0  &
   side_count_for_perimeter = 60  &
   segment_count = 60
!
geometry create shape cylinder  &
   cylinder_name = .Gyro.OuterCage.CYLINDER_6  &
   adams_id = 6  &
   center_marker = .Gyro.OuterCage.MARKER_10  &
   angle_extent = 360.0  &
   length = 100.0  &
   radius = 10.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .Gyro.OuterCage  &
   color = RED  &
   name_visibility = off
!
!--------------------------------- InnerCage ----------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.ground
!
part create rigid_body name_and_position  &
   part_name = .Gyro.InnerCage  &
   adams_id = 3  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.InnerCage
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Gyro.InnerCage.MARKER_2  &
   adams_id = 2  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.InnerCage.cm  &
   adams_id = 7  &
   location = 8.3981255518, 0.0, 0.0  &
   orientation = 270.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Gyro.InnerCage.MARKER_3  &
   adams_id = 3  &
   location = 300.0, 0.0, 0.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.InnerCage.MARKER_14  &
   adams_id = 14  &
   location = 350.0, 0.0, 0.0  &
   orientation = 270.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Gyro.InnerCage.MARKER_15  &
   adams_id = 15  &
   location = 0.0, -300.0, 0.0  &
   orientation = 180.0d, 90.0d, 180.0d
!
part create rigid_body mass_properties  &
   part_name = .Gyro.InnerCage  &
   material_type = .Gyro.steel
!
! ****** Graphics for current part ******
!
geometry create shape torus  &
   adams_id = 2  &
   torus_name = .Gyro.InnerCage.TORUS_2  &
   center_marker = .Gyro.InnerCage.MARKER_2  &
   angle_extent = 360.0  &
   major_radius = 300.0  &
   minor_radius = 10.0  &
   side_count_for_perimeter = 60  &
   segment_count = 60
!
geometry create shape cylinder  &
   cylinder_name = .Gyro.InnerCage.CYLINDER_3  &
   adams_id = 3  &
   center_marker = .Gyro.InnerCage.MARKER_3  &
   angle_extent = 360.0  &
   length = 50.0  &
   radius = 10.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry attributes  &
   geometry_name = .Gyro.InnerCage.CYLINDER_3  &
   visibility = on
!
part attributes  &
   part_name = .Gyro.InnerCage  &
   color = MAIZE  &
   visibility = on  &
   name_visibility = off
!
!-------------------------------- InertiaWheel --------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.ground
!
part create rigid_body name_and_position  &
   part_name = .Gyro.InertiaWheel  &
   adams_id = 4  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.InertiaWheel
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Gyro.InertiaWheel.MARKER_8  &
   adams_id = 8  &
   location = 0.0, 300.0, 0.0  &
   orientation = 0.0d, 90.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.InertiaWheel.cm  &
   adams_id = 17  &
   location = 0.0, 0.0, 0.0  &
   orientation = 90.0d, 90.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.InertiaWheel.MARKER_9  &
   adams_id = 9  &
   location = 0.0, -10.0, 0.0  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Gyro.InertiaWheel.MARKER_16  &
   adams_id = 16  &
   location = 0.0, -300.0, 0.0  &
   orientation = 180.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Gyro.InertiaWheel.MARKER_18  &
   adams_id = 18  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Gyro.InertiaWheel.MARKER_19  &
   adams_id = 19  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Gyro.InertiaWheel  &
   material_type = .Gyro.steel
!
! ****** Graphics for current part ******
!
geometry create shape cylinder  &
   cylinder_name = .Gyro.InertiaWheel.CYLINDER_4  &
   adams_id = 4  &
   center_marker = .Gyro.InertiaWheel.MARKER_8  &
   angle_extent = 360.0  &
   length = 600.0  &
   radius = 10.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
geometry create shape cylinder  &
   cylinder_name = .Gyro.InertiaWheel.CYLINDER_5  &
   adams_id = 5  &
   center_marker = .Gyro.InertiaWheel.MARKER_9  &
   angle_extent = 360.0  &
   length = 20.0  &
   radius = 250.0  &
   side_count_for_body = 20  &
   segment_count_for_ends = 20
!
part attributes  &
   part_name = .Gyro.InertiaWheel  &
   color = MAGENTA  &
   visibility = on  &
   name_visibility = off
!
!--------------------------------- Equations ----------------------------------!
!
!
part create equation differential_equation  &
   differential_equation_name = .Gyro.DIFF_1  &
   adams_id = 1  &
   initial_condition = 0.0  &
   function = ""  &
   implicit = off  &
   static_hold = off
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint spherical  &
   joint_name = .Gyro.JOINT_1  &
   adams_id = 1  &
   i_marker_name = .Gyro.OuterCage.MARKER_11  &
   j_marker_name = .Gyro.ground.MARKER_12
!
constraint attributes  &
   constraint_name = .Gyro.JOINT_1  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Gyro.JOINT_2  &
   adams_id = 2  &
   i_marker_name = .Gyro.OuterCage.MARKER_13  &
   j_marker_name = .Gyro.InnerCage.MARKER_14
!
constraint attributes  &
   constraint_name = .Gyro.JOINT_2  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Gyro.JOINT_3  &
   adams_id = 3  &
   i_marker_name = .Gyro.InnerCage.MARKER_15  &
   j_marker_name = .Gyro.InertiaWheel.MARKER_16  &
   rotational_ic = 0.0d  &
   angular_velocity_ic = 3.6E+004
!
constraint attributes  &
   constraint_name = .Gyro.JOINT_3  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
force create direct single_component_force  &
   single_component_force_name = .Gyro.SFORCE_1  &
   adams_id = 1  &
   type_of_freedom = translational  &
   i_marker_name = .Gyro.InertiaWheel.MARKER_18  &
   j_marker_name = .Gyro.InertiaWheel.MARKER_19  &
   action_only = on  &
   function = ""
!
!---------------------------------- Requests ----------------------------------!
!
!
output_control create request  &
   request_name = .Gyro.r1  &
   adams_id = 1  &
   f2 = ""
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .Gyro.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=yes end_time=1.0 number_of_steps=500 model_name=.Gyro"
!
!------------------------------ Dynamic Graphics ------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Gyro.ground
!
geometry create shape force  &
   force_name = .Gyro.SFORCE_1_force_graphic_1  &
   adams_id = 7  &
   force_element_name = .Gyro.SFORCE_1  &
   applied_at_marker_name = .Gyro.InertiaWheel.MARKER_18
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------------- Measures ----------------------------------!
!
!
measure create function  &
   measure_name = .Gyro.FUNCTION_MEA_1  &
   function = ""  &
   units = "no_units"  &
   create_measure_display = no
!
data_element attributes  &
   data_element_name = .Gyro.FUNCTION_MEA_1  &
   color = WHITE
!
!---------------------------- Function definitions ----------------------------!
!
!
measure modify function  &
   measure_name = .Gyro.FUNCTION_MEA_1  &
   function = "AY(.Gyro.InertiaWheel.cm)*rtod"
!
part modify equation differential_equation  &
   differential_equation_name = .Gyro.DIFF_1  &
   function = "WY(.Gyro.InertiaWheel.cm, .Gyro.ground.MARKER_20, .Gyro.ground.MARKER_20)*rtod"
!
force modify direct single_component_force  &
   single_component_force_name = .Gyro.SFORCE_1  &
   function = "step(time, 0.1,0,0.15,100)*step(time,0.15,100,0.2,0)"
!
output_control modify request  &
   request_name = .Gyro.r1  &
   f2 = "DIF(.Gyro.DIFF_1)"
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
geometry modify shape torus  &
   torus_name = .Gyro.OuterCage.TORUS_1  &
   major_radius = (35cm)  &
   minor_radius = (1cm)
!
geometry modify shape cylinder  &
   cylinder_name = .Gyro.OuterCage.CYLINDER_6  &
   length = (100.0mm)  &
   radius = (1cm)
!
geometry modify shape torus  &
   torus_name = .Gyro.InnerCage.TORUS_2  &
   major_radius = (30cm)  &
   minor_radius = (1cm)
!
geometry modify shape cylinder  &
   cylinder_name = .Gyro.InnerCage.CYLINDER_3  &
   length = (50.0mm)  &
   radius = (1.0cm)
!
geometry modify shape cylinder  &
   cylinder_name = .Gyro.InertiaWheel.CYLINDER_4  &
   length = (600.0mm)  &
   radius = (1.0cm)
!
geometry modify shape cylinder  &
   cylinder_name = .Gyro.InertiaWheel.CYLINDER_5  &
   length = (20.0mm)  &
   radius = (25cm)
!
material modify  &
   material_name = .Gyro.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
geometry modify shape force  &
   force_name = .Gyro.SFORCE_1_force_graphic_1  &
   applied_at_marker_name = (.Gyro.SFORCE_1.i)
!
model display  &
   model_name = Gyro
