!
!-------------------------- Default Units for Model ---------------------------!
!
!
defaults units  &
   length = mm  &
   angle = deg  &
   force = newton  &
   mass = kg  &
   time = sec
!
defaults units  &
   coordinate_system_type = cartesian  &
   orientation_type = body313
!
!------------------------ Default Attributes for Model ------------------------!
!
!
defaults attributes  &
   inheritance = bottom_up  &
   icon_visibility = on  &
   grid_visibility = off  &
   size_of_icons = 50.0  &
   spacing_for_grid = 1000.0
!
!------------------------------ Adams/View Model ------------------------------!
!
!
model create  &
   model_name = Power_Hacksaw
!
view erase
!
!--------------------------------- Materials ----------------------------------!
!
!
material create  &
   material_name = .Power_Hacksaw.steel  &
   adams_id = 1  &
   youngs_modulus = 2.07E+005  &
   poissons_ratio = 0.29  &
   density = 7.801E-006
!
!-------------------------------- Rigid Parts ---------------------------------!
!
! Create parts and their dependent markers and graphics
!
!----------------------------------- ground -----------------------------------!
!
!
! ****** Ground Part ******
!
defaults model  &
   part_name = ground
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_11  &
   adams_id = 11  &
   location = -240.0, -30.0, 25.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_15  &
   adams_id = 15  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_34  &
   adams_id = 34  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_36  &
   adams_id = 36  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_38  &
   adams_id = 38  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.ground.MARKER_41  &
   adams_id = 41  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.ground  &
   material_type = .Power_Hacksaw.steel
!
! ****** Points for current part ******
!
point create  &
   point_name = .Power_Hacksaw.ground.ORIGIN  &
   location = 0.0, 0.0, 0.0
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.ground  &
   name_visibility = off
!
!------------------------------------ Base ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Base  &
   adams_id = 2  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Base
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Base.PSMAR  &
   adams_id = 19  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Base.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Base.cm  &
   adams_id = 20  &
   location = 16.7374695855, -6.5661393596, 101.561130029  &
   orientation = 180.0d, 92.3869384285d, 90.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_2  &
   adams_id = 2  &
   location = 16.7374695855, 21.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_9  &
   adams_id = 9  &
   location = 16.7374695855, 21.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_14  &
   adams_id = 14  &
   location = 16.7374695855, -6.5661393596, 101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_33  &
   adams_id = 33  &
   location = 16.7374695855, 21.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_40  &
   adams_id = 40  &
   location = 16.7374695855, 21.0139628467, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Base.MARKER_43  &
   adams_id = 43  &
   location = 16.7374695855, 21.0139628467, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Base  &
   density = 1.0E-006
!
! ****** Points for current part ******
!
point create  &
   point_name = .Power_Hacksaw.Base.POINT1  &
   location = 16.7374695855, 21.0139628467, 0.0
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Base  &
   color = WHITE
!
!----------------------------------- Link2 ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Link2  &
   adams_id = 3  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Link2
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.PSMAR  &
   adams_id = 21  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Link2.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.cm  &
   adams_id = 22  &
   location = 38.319586507, 42.5960797682, 120.0711181216  &
   orientation = 315.0d, 90.2376109366d, 90.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_3  &
   adams_id = 3  &
   location = 16.7374695855, 21.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_4  &
   adams_id = 4  &
   location = 69.7374695855, 74.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_32  &
   adams_id = 32  &
   location = 38.319586507, 42.5960797682, 120.0711181216  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_35  &
   adams_id = 35  &
   location = 38.319586507, 42.5960797682, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_37  &
   adams_id = 37  &
   location = 38.319586507, 42.5960797682, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link2.MARKER_39  &
   adams_id = 39  &
   location = 38.319586507, 42.5960797682, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Link2  &
   density = 1.0E-006
!
! ****** Points for current part ******
!
point create  &
   point_name = .Power_Hacksaw.Link2.POINT0  &
   location = 38.319586507, 42.5960797682, 0.0
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Link2  &
   color = WHITE
!
!----------------------------------- Link5 ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Link5  &
   adams_id = 4  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Link5
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Link5.PSMAR  &
   adams_id = 23  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Link5.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Link5.cm  &
   adams_id = 24  &
   location = -127.406966851, 86.858732557, 83.438550582  &
   orientation = 258.3116242827d, 89.3185224078d, 88.220672549d
!
marker create  &
   marker_name = .Power_Hacksaw.Link5.MARKER_8  &
   adams_id = 8  &
   location = 16.7374695855, 21.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link5.MARKER_17  &
   adams_id = 17  &
   location = -217.8738432523, 91.4233267564, 108.6863843333  &
   orientation = 270.0d, 90.0d, 180.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Link5  &
   density = 1.0
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Link5  &
   color = WHITE  &
   visibility = on
!
!----------------------------------- Link4 ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Link4  &
   adams_id = 5  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Link4
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.PSMAR  &
   adams_id = 25  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Link4.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.cm  &
   adams_id = 26  &
   location = -217.8738432523, 91.4233267564, 108.6863843333  &
   orientation = 269.9667597275d, 90.01476827d, 101.9877133996d
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.MARKER_7  &
   adams_id = 7  &
   location = -97.9407937643, 46.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.MARKER_13  &
   adams_id = 13  &
   location = -217.9407937643, 1.9247316853, 126.500000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.MARKER_16  &
   adams_id = 16  &
   location = -217.8738432523, 91.4233267564, 108.6863843333  &
   orientation = 270.0d, 90.0d, 180.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link4.MARKER_42  &
   adams_id = 42  &
   location = -97.9407937643, 1.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Link4  &
   density = 1.0E-006
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Link4  &
   color = WHITE
!
!------------------------------------ Saw -------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Saw  &
   adams_id = 6  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Saw
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Saw.PSMAR  &
   adams_id = 27  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Saw.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Saw.cm  &
   adams_id = 28  &
   location = -217.9407937643, 1.9247316853, 126.500000268  &
   orientation = 270.0d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Saw.MARKER_12  &
   adams_id = 12  &
   location = -217.9407937643, 1.9247316853, 126.500000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Saw  &
   density = 1.0E-006
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Saw  &
   color = WHITE
!
!----------------------------------- Link3 ------------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Link3  &
   adams_id = 7  &
   location = -16.7374695855, 6.5661393596, -101.561130029  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Link3
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Link3.PSMAR  &
   adams_id = 29  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker attributes  &
   marker_name = .Power_Hacksaw.Link3.PSMAR  &
   visibility = off
!
marker create  &
   marker_name = .Power_Hacksaw.Link3.cm  &
   adams_id = 30  &
   location = -14.1016620894, 60.0139628467, 130.000000268  &
   orientation = 279.480149008d, 90.0d, 90.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link3.MARKER_5  &
   adams_id = 5  &
   location = 69.7374695855, 74.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Link3.MARKER_6  &
   adams_id = 6  &
   location = -97.9407937643, 46.0139628467, 125.000000268  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Link3  &
   density = 1.0E-006
!
! ****** Graphics for current part ******
!
part attributes  &
   part_name = .Power_Hacksaw.Link3  &
   color = WHITE
!
!--------------------------------- Work_Piece ---------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
part create rigid_body name_and_position  &
   part_name = .Power_Hacksaw.Work_Piece  &
   adams_id = 8  &
   location = 0.0, 0.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.Work_Piece
!
! ****** Markers for current part ******
!
marker create  &
   marker_name = .Power_Hacksaw.Work_Piece.MARKER_1  &
   adams_id = 1  &
   location = -265.0, -55.0, 0.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Work_Piece.cm  &
   adams_id = 31  &
   location = -240.0, -30.0, 25.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
marker create  &
   marker_name = .Power_Hacksaw.Work_Piece.MARKER_10  &
   adams_id = 10  &
   location = -240.0, -30.0, 25.0  &
   orientation = 0.0d, 0.0d, 0.0d
!
part create rigid_body mass_properties  &
   part_name = .Power_Hacksaw.Work_Piece  &
   material_type = .Power_Hacksaw.steel
!
! ****** Graphics for current part ******
!
geometry create shape block  &
   block_name = .Power_Hacksaw.Work_Piece.BOX_8  &
   adams_id = 8  &
   corner_marker = .Power_Hacksaw.Work_Piece.MARKER_1  &
   diag_corner_coords = 50.0, 50.0, 50.0
!
part attributes  &
   part_name = .Power_Hacksaw.Work_Piece  &
   color = YELLOW  &
   name_visibility = off
!
! ****** Graphics from Parasolid file ******
!
file parasolid read  &
   file_name = "Power_Hacksaw.xmt_txt"  &
   model_name = .Power_Hacksaw
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Base.SOLID1  &
   color = Gray
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Link2.SOLID2  &
   color = RED
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Link5.SOLID3  &
   color = GREEN
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Link4.SOLID4  &
   color = MAGENTA
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Saw.SOLID5  &
   color = Gray
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.Link3.SOLID6  &
   color = MAIZE
!
!---------------------------------- Contacts ----------------------------------!
!
!
contact create  &
   contact_name = .Power_Hacksaw.CONTACT_1  &
   adams_id = 1  &
   i_geometry_name = .Power_Hacksaw.Saw.SOLID5  &
   j_geometry_name = .Power_Hacksaw.Work_Piece.BOX_8  &
   penalty = 1.0E+010  &
   restitution_coefficient = 0.0  &
   augmented_lagrangian_formulation = no  &
   coulomb_friction = on  &
   mu_static = 0.3  &
   mu_dynamic = 0.1  &
   stiction_transition_velocity = 100.0  &
   friction_transition_velocity = 1000.0
!
!----------------------------------- Joints -----------------------------------!
!
!
constraint create joint revolute  &
   joint_name = .Power_Hacksaw.JOINT_1  &
   adams_id = 1  &
   i_marker_name = .Power_Hacksaw.Base.MARKER_2  &
   j_marker_name = .Power_Hacksaw.Link2.MARKER_3
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_1  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Power_Hacksaw.JOINT_2  &
   adams_id = 2  &
   i_marker_name = .Power_Hacksaw.Link2.MARKER_4  &
   j_marker_name = .Power_Hacksaw.Link3.MARKER_5
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_2  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Power_Hacksaw.JOINT_3  &
   adams_id = 3  &
   i_marker_name = .Power_Hacksaw.Link3.MARKER_6  &
   j_marker_name = .Power_Hacksaw.Link4.MARKER_7
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_3  &
   name_visibility = off
!
constraint create joint revolute  &
   joint_name = .Power_Hacksaw.JOINT_4  &
   adams_id = 4  &
   i_marker_name = .Power_Hacksaw.Link5.MARKER_8  &
   j_marker_name = .Power_Hacksaw.Base.MARKER_9
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_4  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .Power_Hacksaw.JOINT_5  &
   adams_id = 5  &
   i_marker_name = .Power_Hacksaw.Work_Piece.MARKER_10  &
   j_marker_name = .Power_Hacksaw.ground.MARKER_11
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_5  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .Power_Hacksaw.JOINT_6  &
   adams_id = 6  &
   i_marker_name = .Power_Hacksaw.Saw.MARKER_12  &
   j_marker_name = .Power_Hacksaw.Link4.MARKER_13
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_6  &
   name_visibility = off
!
constraint create joint fixed  &
   joint_name = .Power_Hacksaw.JOINT_7  &
   adams_id = 7  &
   i_marker_name = .Power_Hacksaw.Base.MARKER_14  &
   j_marker_name = .Power_Hacksaw.ground.MARKER_15
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_7  &
   name_visibility = off
!
constraint create joint translational  &
   joint_name = .Power_Hacksaw.JOINT_8  &
   adams_id = 8  &
   i_marker_name = .Power_Hacksaw.Link4.MARKER_16  &
   j_marker_name = .Power_Hacksaw.Link5.MARKER_17
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.JOINT_8  &
   name_visibility = off
!
!----------------------------------- Forces -----------------------------------!
!
!
!----------------------------- Simulation Scripts -----------------------------!
!
!
simulation script create  &
   sim_script_name = .Power_Hacksaw.Last_Sim  &
   commands =   &
              "simulation single_run transient type=auto_select initial_static=no end_time=25.0 step_size=0.1 model_name=.Power_Hacksaw"
!
!------------------------------ Dynamic Graphics ------------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
geometry create shape gcontact  &
   contact_force_name = .Power_Hacksaw.GCONTACT_11  &
   adams_id = 11  &
   contact_element_name = .Power_Hacksaw.CONTACT_1  &
   force_display = components
!
geometry attributes  &
   geometry_name = .Power_Hacksaw.GCONTACT_11  &
   color = RED
!
!---------------------------------- Motions -----------------------------------!
!
!
constraint create motion_generator  &
   motion_name = .Power_Hacksaw.MOTION_1  &
   adams_id = 1  &
   type_of_freedom = rotational  &
   joint_name = .Power_Hacksaw.JOINT_1  &
   function = ""
!
constraint attributes  &
   constraint_name = .Power_Hacksaw.MOTION_1  &
   name_visibility = off
!
!---------------------------------- Accgrav -----------------------------------!
!
!
force create body gravitational  &
   gravity_field_name = gravity  &
   x_component_gravity = 0.0  &
   y_component_gravity = -9806.65  &
   z_component_gravity = 0.0
!
!----------------------------- Analysis settings ------------------------------!
!
!
!---------------------------------- Measures ----------------------------------!
!
!
measure create pt2pt  &
   measure_name = .Power_Hacksaw.stroke  &
   from_point = .Power_Hacksaw.Link4.MARKER_42  &
   to_point = .Power_Hacksaw.Base.MARKER_43  &
   characteristic = translational_displacement  &
   component = x_component
!
data_element attributes  &
   data_element_name = .Power_Hacksaw.stroke  &
   color = WHITE
!
measure create function  &
   measure_name = .Power_Hacksaw.Angle_Link2toBase  &
   function = ""  &
   units = "angle"
!
data_element attributes  &
   data_element_name = .Power_Hacksaw.Angle_Link2toBase  &
   color = WHITE
!
!---------------------------- Function definitions ----------------------------!
!
!
constraint modify motion_generator  &
   motion_name = .Power_Hacksaw.MOTION_1  &
   function = "55d+30.0d * time"
!
measure modify function  &
   measure_name = .Power_Hacksaw.Angle_Link2toBase  &
   function = "AZ(.Power_Hacksaw.Base.MARKER_2, .Power_Hacksaw.Link2.MARKER_3)"
!
measure_display create  &
   mea_display = .Power_Hacksaw.Angle_Link2toBase_display  &
   measure_name = .Power_Hacksaw.Angle_Link2toBase
!
!--------------------------- Expression definitions ---------------------------!
!
!
defaults coordinate_system  &
   default_coordinate_system = ground
!
marker modify  &
   marker_name = .Power_Hacksaw.ground.MARKER_15  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))
!
marker modify  &
   marker_name = .Power_Hacksaw.ground.MARKER_34  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))
!
marker modify  &
   marker_name = .Power_Hacksaw.ground.MARKER_36  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))
!
marker modify  &
   marker_name = .Power_Hacksaw.ground.MARKER_38  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))
!
marker modify  &
   marker_name = .Power_Hacksaw.ground.MARKER_41  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))
!
material modify  &
   material_name = .Power_Hacksaw.steel  &
   youngs_modulus = (2.07E+011(Newton/meter**2))  &
   density = (7801.0(kg/meter**3))
!
marker modify  &
   marker_name = .Power_Hacksaw.Base.MARKER_14  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.ground.ORIGIN))  &
   relative_to = .Power_Hacksaw.Base
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
marker modify  &
   marker_name = .Power_Hacksaw.Base.MARKER_40  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.Base.POINT1))  &
   relative_to = .Power_Hacksaw.Base
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
marker modify  &
   marker_name = .Power_Hacksaw.Base.MARKER_43  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.Base.POINT1))  &
   relative_to = .Power_Hacksaw.Base
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
marker modify  &
   marker_name = .Power_Hacksaw.Link2.MARKER_35  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.Link2.POINT0))  &
   relative_to = .Power_Hacksaw.Link2
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
marker modify  &
   marker_name = .Power_Hacksaw.Link2.MARKER_37  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.Link2.POINT0))  &
   relative_to = .Power_Hacksaw.Link2
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
marker modify  &
   marker_name = .Power_Hacksaw.Link2.MARKER_39  &
   location =   &
      (LOC_RELATIVE_TO({0, 0, 0}, .Power_Hacksaw.Link2.POINT0))  &
   relative_to = .Power_Hacksaw.Link2
!
defaults coordinate_system  &
   default_coordinate_system = .Power_Hacksaw.ground
!
geometry modify shape block  &
   block_name = .Power_Hacksaw.Work_Piece.BOX_8  &
   diag_corner_coords =   &
      (50mm),  &
      (50mm),  &
      (50mm)
!
model display  &
   model_name = Power_Hacksaw
